/**
 * Execute a HTTPS request
 * @param uri - The URI
 * @param requestOptions - The RequestOptions to use (depending on the runtime context, either Node.js RequestOptions or Web Fetch init)
 * @param data - Data to send to the URI (e.g. POST data)
 * @returns - The response body as ArrayBuffer
 */
export declare const fetch: (uri: string, requestOptions?: Record<string, unknown>, data?: ArrayBuffer) => Promise<ArrayBuffer>;
type FetchRequestOptions = Record<string, unknown>;
/** Interface for JS objects that can be used as Fetcher */
export interface Fetcher {
    /**
     * Execute a HTTPS request
     * @param uri - The URI
     * @param requestOptions - The RequestOptions to use (depending on the runtime context, either Node.js RequestOptions or Web Fetch init)
     * @param data - Data to send to the URI (e.g. POST data)
     * @returns - The response body as ArrayBuffer
     */
    fetch: (uri: string, requestOptions?: FetchRequestOptions, data?: ArrayBuffer) => Promise<ArrayBuffer>;
}
/**
 * HTTPS Fetcher. The fetch implementation has 1 immediate retry in case of errors
 *
 * @param defaultRequestOptions - The default RequestOptions to use on individual HTTPS requests
 *   (depending on the runtime context, either Node.js RequestOptions or Web Fetch init)
 */
export declare class SimpleFetcher implements Fetcher {
    defaultRequestOptions: FetchRequestOptions;
    constructor(props?: {
        defaultRequestOptions?: FetchRequestOptions;
    });
    /**
     * Execute a HTTPS request (with 1 immediate retry in case of errors)
     * @param uri - The URI
     * @param requestOptions - The RequestOptions to use (depending on the runtime context, either Node.js RequestOptions or Web Fetch init)
     * @param data - Data to send to the URI (e.g. POST data)
     * @returns - The response body as ArrayBuffer
     */
    fetch(uri: string, requestOptions?: FetchRequestOptions, data?: ArrayBuffer): Promise<ArrayBuffer>;
}
export {};
